==================
Simple Django Blog
==================


.. image:: https://img.shields.io/pypi/v/djcms_blog.svg
        :target: https://pypi.python.org/pypi/djcms_blog

.. image:: https://img.shields.io/travis/carlosmart626/djcms_blog.svg
        :target: https://travis-ci.org/carlosmart626/djcms_blog

.. image:: https://readthedocs.org/projects/djcms-blog/badge/?version=latest
        :target: https://djcms-blog.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/CarlosMart626/djcms_blog/python-3-shield.svg

.. image:: https://pyup.io/repos/github/CarlosMart626/djcms_blog/shield.svg




Simple Django Blog app using Markdown


* Free software: MIT license
* Documentation: https://djcms-blog.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
